@@ -35,6 +35,14 @@ enum program_component_id {
 	NR_PROGRAM_COMPONENTS
 };
 
+/* Types of SCSI disk layouts */
+enum scsi_layout {
+	scsi_layout_pcbios,
+	scsi_layout_sun,
+	scsi_layout_sgi,
+	scsi_layout_unknown
+};
+
 struct component_loc {
 	address_t addr;
 	size_t size;
@@ -76,6 +84,19 @@ struct install_set {
 
 extern struct component_footer component_footers[NR_PROGRAM_COMPONENTS];
 
+/* Determine SCSI disk layout from the specified BOOTBLOCK. */
+static inline enum scsi_layout get_scsi_layout(unsigned char *bootblock)
+{
+	if ((bootblock[510] == 0x55) && (bootblock[511] == 0xaa))
+		return scsi_layout_pcbios;
+	else if ((bootblock[508] == 0xda) && (bootblock[509] == 0xbe))
+		return scsi_layout_sun;
+	else if ((bootblock[0] == 0x0b) && (bootblock[1] == 0xe5) &&
+		 (bootblock[2] == 0xa9) && (bootblock[3] == 0x41))
+		return scsi_layout_sgi;
+	return scsi_layout_unknown;
+}
+
 static inline component_type component_type_by_id(enum program_component_id id)
 {
 	return component_footers[id].type;
